==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiWidgets/QAccessibleWidget_shell.h <==
#ifndef QACCESSIBLEWIDGET_SHELL_H
#define QACCESSIBLEWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qaccessiblewidget.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <QtGui/qcolor.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QAccessibleWidget_shell : public QAccessibleWidget, public QtJambiShellInterface
{
public:
    QAccessibleWidget_shell(QWidget* o0, QAccessible::Role r1 = QAccessible::Client, const QString& name2 = QString());
    ~QAccessibleWidget_shell() override;

    QStringList actionNames() const override;
    QColor backgroundColor() const override;
    QAccessibleInterface* child(int index0) const override;
    QAccessibleInterface* childAt(int x0, int y1) const override;
    int childCount() const override;
    void doAction(const QString& actionName0) override;
    QAccessibleInterface* focusChild() const override;
    QColor foregroundColor() const override;
    int indexOfChild(const QAccessibleInterface* child0) const override;
    bool isValid() const override;
    QStringList keyBindingsForAction(const QString& actionName0) const override;
    QString localizedActionDescription(const QString& name0) const override;
    QString localizedActionName(const QString& name0) const override;
    QObject* object() const override;
    QAccessibleInterface* parent() const override;
    QRect rect() const override;
    QList<QPair<QAccessibleInterface*, QAccessible::Relation> > relations(QAccessible::Relation match0) const override;
    QAccessible::Role role() const override;
    void setText(QAccessible::Text t0, const QString& text1) override;
    QAccessible::State state() const override;
    QString text(QAccessible::Text t0) const override;
    QWindow* window() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleWidget_access : public QAccessibleWidget
{
    void __qt_addControllingSignal_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring signal0);
    jobject __qt_parentObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_widget(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_actionNames(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_backgroundColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_child_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_childCount(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doAction_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0);
    jobject __qt_focusChild(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_foregroundColor(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_indexOfChild_const_QAccessibleInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID child0) const;
    jboolean __qt_isValid(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_keyBindingsForAction_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0) const;
    jstring __qt_localizedActionDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jstring __qt_localizedActionName_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_parent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_rect(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_relations_QAccessible_Relation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint match0) const;
    jint __qt_role(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_state(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_text_QAccessible_Text_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint t0) const;
    jobject __qt_window(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QACCESSIBLEWIDGET_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiWidgets/QAccessibleWidget_shell.h <==
#ifndef QACCESSIBLEWIDGET_SHELL_H
#define QACCESSIBLEWIDGET_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtWidgets/qaccessiblewidget.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qcontainerfwd.h>
#include <QtCore/qobject.h>
#include <QtCore/qrect.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qaccessible_base.h>
#include <QtGui/qcolor.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


class QAccessibleWidget_shell : public QAccessibleWidget, public QtJambiShellInterface
{
public:
    QAccessibleWidget_shell(QWidget* o0, QAccessible::Role r1 = QAccessible::Client, const QString& name2 = QString());
    ~QAccessibleWidget_shell() override;

    QStringList actionNames() const override;
    QColor backgroundColor() const override;
    QAccessibleInterface* child(int index0) const override;
    QAccessibleInterface* childAt(int x0, int y1) const override;
    int childCount() const override;
    void doAction(const QString& actionName0) override;
    QAccessibleInterface* focusChild() const override;
    QColor foregroundColor() const override;
    int indexOfChild(const QAccessibleInterface* child0) const override;
    bool isValid() const override;
    QStringList keyBindingsForAction(const QString& actionName0) const override;
    QString localizedActionDescription(const QString& name0) const override;
    QString localizedActionName(const QString& name0) const override;
    QObject* object() const override;
    QAccessibleInterface* parent() const override;
    QRect rect() const override;
    QList<QPair<QAccessibleInterface*, QAccessible::Relation> > relations(QAccessible::Relation match0) const override;
    QAccessible::Role role() const override;
    void setText(QAccessible::Text t0, const QString& text1) override;
    QAccessible::State state() const override;
    QString text(QAccessible::Text t0) const override;
    QWindow* window() const override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAccessibleWidget_access : public QAccessibleWidget
{
    void __qt_addControllingSignal_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring signal0);
    jobject __qt_parentObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_widget_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_actionNames_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_backgroundColor_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_child_int_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint index0) const;
    jint __qt_childCount_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_doAction_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0);
    jobject __qt_focusChild_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_foregroundColor_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jint __qt_indexOfChild_const_QAccessibleInterface_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID child0) const;
    jboolean __qt_isValid_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_keyBindingsForAction_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring actionName0) const;
    jstring __qt_localizedActionDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jstring __qt_localizedActionName_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jobject __qt_parent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_rect_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_relations_QAccessible_Relation_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint match0) const;
    jint __qt_role_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_state_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_text_QAccessible_Text_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint t0) const;
    jobject __qt_window_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QACCESSIBLEWIDGET_SHELL_H
